@@ -9,4 +9,4 @@ try:
     memoize = partial(cache.memoize, key=dask.base.tokenize)
 except ImportError:
     cache = {}
-    memoize = lambda x: x  # type: ignore
+    memoize = lambda x: x  # type: ignore[assignment]
